==> SQLAlchemy-Continuum-1.3.5.tar.gz: SQLAlchemy-Continuum-1.3.5/tests/test_mapper_args.py <==
import sqlalchemy as sa
from sqlalchemy_continuum import version_class
from tests import TestCase


class TestColumnPrefix(TestCase):
    def create_models(self):
        class TextItem(self.Model):
            __tablename__ = 'text_item'
            __versioned__ = {
                'base_classes': (self.Model, )
            }
            id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)

            name = sa.Column(sa.Unicode(255))

            __mapper_args__ = {
                'column_prefix': '_'
            }

        self.TextItem = TextItem

    def setup_method(self, method):
        TestCase.setup_method(self, method)
        self.TextItemVersion = version_class(self.TextItem)

    def test_supports_column_prefix(self):
        assert self.TextItemVersion._id
        assert self.TextItem._id


class TestOrderByWithStringArg(TestCase):
    def create_models(self):
        class TextItem(self.Model):
            __tablename__ = 'text_item'
            __versioned__ = {
                'base_classes': (self.Model, )
            }
            id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)

            name = sa.Column(sa.Unicode(255))

            __mapper_args__ = {
                'order_by': 'id',
                'column_prefix': '_'
            }

        self.TextItem = TextItem

    def setup_method(self, method):
        TestCase.setup_method(self, method)
        self.TextItemVersion = version_class(self.TextItem)

    def test_reflects_order_by(self):
        assert self.TextItemVersion.__mapper_args__['order_by'] == 'id'


class TestOrderByWithInstrumentedAttribute(TestCase):
    def create_models(self):
        class TextItem(self.Model):
            __tablename__ = 'text_item'
            __versioned__ = {
                'base_classes': (self.Model, )
            }
            id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)

            name = sa.Column(sa.Unicode(255))

            __mapper_args__ = {
                'order_by': id
            }

        self.TextItem = TextItem

    def setup_method(self, method):
        TestCase.setup_method(self, method)
        self.TextItemVersion = version_class(self.TextItem)

    def test_reflects_order_by(self):
        assert 'order_by' not in self.TextItemVersion.__mapper_args__

==> SQLAlchemy-Continuum-1.3.12.tar.gz: SQLAlchemy-Continuum-1.3.12/tests/test_mapper_args.py <==
from pytest import mark
from packaging import version

import sqlalchemy as sa
from sqlalchemy_continuum import version_class
from tests import TestCase


class TestColumnPrefix(TestCase):
    def create_models(self):
        class TextItem(self.Model):
            __tablename__ = 'text_item'
            __versioned__ = {
                'base_classes': (self.Model, )
            }
            id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)

            name = sa.Column(sa.Unicode(255))

            __mapper_args__ = {
                'column_prefix': '_'
            }

        self.TextItem = TextItem

    def setup_method(self, method):
        TestCase.setup_method(self, method)
        self.TextItemVersion = version_class(self.TextItem)

    def test_supports_column_prefix(self):
        assert self.TextItemVersion._id
        assert self.TextItem._id


@mark.skipif("version.parse(sa.__version__) >= version.parse('1.4')")
class TestOrderByWithStringArg(TestCase):
    def create_models(self):
        class TextItem(self.Model):
            __tablename__ = 'text_item'
            __versioned__ = {
                'base_classes': (self.Model, )
            }
            id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)

            name = sa.Column(sa.Unicode(255))

            __mapper_args__ = {
                'order_by': 'id',
                'column_prefix': '_'
            }

        self.TextItem = TextItem

    def setup_method(self, method):
        TestCase.setup_method(self, method)
        self.TextItemVersion = version_class(self.TextItem)

    def test_reflects_order_by(self):
        assert self.TextItemVersion.__mapper_args__['order_by'] == 'id'


@mark.skipif("version.parse(sa.__version__) >= version.parse('1.4')")
class TestOrderByWithInstrumentedAttribute(TestCase):
    def create_models(self):
        class TextItem(self.Model):
            __tablename__ = 'text_item'
            __versioned__ = {
                'base_classes': (self.Model, )
            }
            id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)

            name = sa.Column(sa.Unicode(255))

            __mapper_args__ = {
                'order_by': id
            }

        self.TextItem = TextItem

    def setup_method(self, method):
        TestCase.setup_method(self, method)
        self.TextItemVersion = version_class(self.TextItem)

    def test_reflects_order_by(self):
        assert 'order_by' not in self.TextItemVersion.__mapper_args__
